@@ -1,13 +1,13 @@
 package Map::Tube::Exception;
 $Map::Tube::Exception::AUTHORITY = 'cpan:MANWAR';
-$Map::Tube::Exception::VERSION = '3.21';
+$Map::Tube::Exception::VERSION = '3.22';
 =head1 NAME
 
 Map::Tube::Exception - Base exception package as Moo Role for Map::Tube::* family.
 
 =head1 VERSION
 
-version 3.21
+version 3.22
 
 =cut
 
@@ -78,11 +78,12 @@ Map::Tube and it's Map::Tube::* family. It has been re-structured in the process
     |     129     | Invalid station structure.                                  |
     |     130     | Invalid background color.                                   |
     |     131     | Invalid color name.                                         |
+    |     132     | Invalid station line id.                                    |
     +-------------+-------------------------------------------------------------+
 
 =head1 AUTHOR
 
-Mohammad S Anwar, C<< <mohammad.anwar at yahoo.com> >>
+Mohammad Sajid Anwar, C<< <mohammad.anwar at yahoo.com> >>
 
 =head1 REPOSITORY
 
@@ -90,8 +91,7 @@ L<https://github.com/manwar/Map-Tube-Exception>
 
 =head1 BUGS
 
-Please  report  any  bugs  or  feature requests to C<bug-map-tube-exception at rt.cpan.org>,
-or through the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=Map-Tube-Exception>.
+Please report any bugs or feature requests through the web interface at L<https://github.com/manwar/Map-Tube-Exception/issues>.
 I will be notified, and then you'll automatically be notified of progress on your
 bug as I make changes.
 
@@ -105,27 +105,23 @@ You can also look for information at:
 
 =over 4
 
-=item * RT: CPAN's request tracker (report bugs here)
+=item * BUG Report
 
-L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=Map-Tube-Exception>
-
-=item * AnnoCPAN: Annotated CPAN documentation
-
-L<http://annocpan.org/dist/Map-Tube-Exception>
+L<https://github.com/manwar/Map-Tube-Exception/issues>
 
 =item * CPAN Ratings
 
 L<http://cpanratings.perl.org/d/Map-Tube-Exception>
 
-=item * Search CPAN
+=item * Search MetaCPAN
 
-L<http://search.cpan.org/dist/Map-Tube-Exception/>
+L<https://metacpan.org/dist/Map-Tube-Exception/>
 
 =back
 
 =head1 LICENSE AND COPYRIGHT
 
-Copyright (C) 2015 - 2016 Mohammad S Anwar.
+Copyright (C) 2015 - 2024 Mohammad Sajid Anwar.
 
 This  program  is  free software; you can redistribute it and/or  modify it under
 the  terms  of the the Artistic License (2.0).  You may obtain a copy of the full
